### ENFA example ###

# we load necessary libraries
library(adehabitatHS)
library(pROC)
library(biomod2)

setwd("~/Desktop/Lavoro/Didattica/Corso_ENM/2021/class05/exercises/ENFA")

# we use tha same date as in the BIOMOD example
mammals_data <- read.csv("mammals_and_bioclim_table.csv", row.names=1)

#first, we perform a PCA analysis on the variables
pc <- dudi.pca(mammals_data[,c("bio3", "bio7", "bio11", "bio12")], scannf=FALSE, nf = 2)

# then we fit the model by using the results of the PCA
en <- enfa(pc, mammals_data$VulpesVulpes, scan=FALSE)

# we can output the result of the PCA, amnd compare the niche of the species
# with the available conditions in the ecological space
par(mfrow=c(1,2))
scatterniche(en$li,mammals_data$VulpesVulpes, pts=T)  # plot the niche
s.arrow(cor(pc$tab,en$li)) # meaning of the axes

# let's print out the model in the geographic space
par(mfrow=c(2,2))
level.plot(mammals_data$VulpesVulpes, XY=mammals_data[,c("X_WGS84", "Y_WGS84")], color.gradient = "grey", cex=0.3,show.scale=F, title="Original data")
level.plot(en$li[,1], XY=mammals_data[,c("X_WGS84", "Y_WGS84")], color.gradient = "grey", cex=0.3,show.scale=F, title="ENFA")

roc_enfa <- roc(mammals_data$VulpesVulpes, en$li[,1])
threshold_enfa <- coords(roc_enfa, "best", ret=c("threshold"), transpose = "TRUE")

Pred01=as.numeric(en$li[,1] > threshold_enfa)
level.plot(Pred01, XY=mammals_data[,c("X_WGS84", "Y_WGS84")], color.gradient = "grey", cex=0.3,show.scale=F, title="ENFA binary")

